# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grid/v1/tensorboard_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from grid.protos.grid.v1 import metadata_pb2 as grid_dot_v1_dot_metadata__pb2
from grid.protos.grid.v1 import event_pb2 as grid_dot_v1_dot_event__pb2
from grid.protos.grid.v1 import tensorboard_pb2 as grid_dot_v1_dot_tensorboard__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='grid/v1/tensorboard_service.proto',
  package='grid.v1',
  syntax='proto3',
  serialized_options=b'Z0github.com/gridai/grid/grid-backend/apis/grid/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n!grid/v1/tensorboard_service.proto\x12\x07grid.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x16grid/v1/metadata.proto\x1a\x13grid/v1/event.proto\x1a\x19grid/v1/tensorboard.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"R\n\x18\x43reateTensorboardRequest\x12\x36\n\x0btensorboard\x18\x01 \x01(\x0b\x32\x14.grid.v1.TensorboardR\x0btensorboard\"S\n\x19\x43reateTensorboardResponse\x12\x36\n\x0btensorboard\x18\x01 \x01(\x0b\x32\x14.grid.v1.TensorboardR\x0btensorboard\"\'\n\x15GetTensorboardRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"P\n\x16GetTensorboardResponse\x12\x36\n\x0btensorboard\x18\x01 \x01(\x0b\x32\x14.grid.v1.TensorboardR\x0btensorboard\"\xf1\x02\n\x17ListTensorboardsRequest\x12%\n\x0e\x63ontinue_token\x18\x01 \x01(\tR\rcontinueToken\x12)\n\x10resource_version\x18\x02 \x01(\tR\x0fresourceVersion\x12\x14\n\x05limit\x18\x03 \x01(\x03R\x05limit\x12\x19\n\x08user_ids\x18\x04 \x03(\tR\x07userIds\x12\x1d\n\ncluster_id\x18\x05 \x01(\tR\tclusterId\x12\x41\n\x0e\x63reated_before\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\rcreatedBefore\x12\x34\n\x08phase_in\x18\x07 \x03(\x0e\x32\x19.grid.v1.TensorboardStateR\x07phaseIn\x12;\n\x0cphase_not_in\x18\x08 \x03(\x0e\x32\x19.grid.v1.TensorboardStateR\nphaseNotIn\"\xa4\x01\n\x18ListTensorboardsResponse\x12\x36\n\x0btensorboard\x18\x01 \x03(\x0b\x32\x14.grid.v1.TensorboardR\x0btensorboard\x12%\n\x0e\x63ontinue_token\x18\x02 \x01(\tR\rcontinueToken\x12)\n\x10resource_version\x18\x03 \x01(\tR\x0fresourceVersion\"R\n\x18UpdateTensorboardRequest\x12\x36\n\x0btensorboard\x18\x01 \x01(\x0b\x32\x14.grid.v1.TensorboardR\x0btensorboard\"S\n\x19UpdateTensorboardResponse\x12\x36\n\x0btensorboard\x18\x01 \x01(\x0b\x32\x14.grid.v1.TensorboardR\x0btensorboard\"X\n\x1eUpdateTensorboardStatusRequest\x12\x36\n\x0btensorboard\x18\x01 \x01(\x0b\x32\x14.grid.v1.TensorboardR\x0btensorboard\"Y\n\x1fUpdateTensorboardStatusResponse\x12\x36\n\x0btensorboard\x18\x01 \x01(\x0b\x32\x14.grid.v1.TensorboardR\x0btensorboard\"R\n\x18\x44\x65leteTensorboardRequest\x12\x36\n\x0btensorboard\x18\x01 \x01(\x0b\x32\x14.grid.v1.TensorboardR\x0btensorboard\"S\n\x19\x44\x65leteTensorboardResponse\x12\x36\n\x0btensorboard\x18\x01 \x01(\x0b\x32\x14.grid.v1.TensorboardR\x0btensorboard\"\xcb\x02\n\x18WatchTensorboardsRequest\x12)\n\x10resource_version\x18\x01 \x01(\tR\x0fresourceVersion\x12\x14\n\x05limit\x18\x02 \x01(\x03R\x05limit\x12\x19\n\x08user_ids\x18\x04 \x03(\tR\x07userIds\x12\x1d\n\ncluster_id\x18\x05 \x01(\tR\tclusterId\x12\x41\n\x0e\x63reated_before\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\rcreatedBefore\x12\x34\n\x08phase_in\x18\x07 \x03(\x0e\x32\x19.grid.v1.TensorboardStateR\x07phaseIn\x12;\n\x0cphase_not_in\x18\x08 \x03(\x0e\x32\x19.grid.v1.TensorboardStateR\nphaseNotIn\"\xa6\x01\n\x19WatchTensorboardsResponse\x12)\n\x10resource_version\x18\x01 \x01(\tR\x0fresourceVersion\x12&\n\x04type\x18\x02 \x01(\x0e\x32\x12.grid.v1.EventTypeR\x04type\x12\x36\n\x0btensorboard\x18\x03 \x01(\x0b\x32\x14.grid.v1.TensorboardR\x0btensorboard2\xfc\x06\n\x12TensorboardService\x12|\n\x11\x43reateTensorboard\x12!.grid.v1.CreateTensorboardRequest\x1a\".grid.v1.CreateTensorboardResponse\" \x82\xd3\xe4\x93\x02\x1a\"\x15/v1/core/tensorboards:\x01*\x12u\n\x0eGetTensorboard\x12\x1e.grid.v1.GetTensorboardRequest\x1a\x1f.grid.v1.GetTensorboardResponse\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/v1/core/tensorboards/{id}\x12v\n\x10ListTensorboards\x12 .grid.v1.ListTensorboardsRequest\x1a!.grid.v1.ListTensorboardsResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/v1/core/tensorboards\x12\x96\x01\n\x11UpdateTensorboard\x12!.grid.v1.UpdateTensorboardRequest\x1a\".grid.v1.UpdateTensorboardResponse\":\x82\xd3\xe4\x93\x02\x34\x1a//v1/core/tensorboards/{tensorboard.metadata.id}:\x01*\x12l\n\x17UpdateTensorboardStatus\x12\'.grid.v1.UpdateTensorboardStatusRequest\x1a(.grid.v1.UpdateTensorboardStatusResponse\x12\x93\x01\n\x11\x44\x65leteTensorboard\x12!.grid.v1.DeleteTensorboardRequest\x1a\".grid.v1.DeleteTensorboardResponse\"7\x82\xd3\xe4\x93\x02\x31*//v1/core/tensorboards/{tensorboard.metadata.id}\x12\\\n\x11WatchTensorboards\x12!.grid.v1.WatchTensorboardsRequest\x1a\".grid.v1.WatchTensorboardsResponse0\x01\x42\x32Z0github.com/gridai/grid/grid-backend/apis/grid/v1b\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,grid_dot_v1_dot_metadata__pb2.DESCRIPTOR,grid_dot_v1_dot_event__pb2.DESCRIPTOR,grid_dot_v1_dot_tensorboard__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])




_CREATETENSORBOARDREQUEST = _descriptor.Descriptor(
  name='CreateTensorboardRequest',
  full_name='grid.v1.CreateTensorboardRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tensorboard', full_name='grid.v1.CreateTensorboardRequest.tensorboard', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='tensorboard', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=181,
  serialized_end=263,
)


_CREATETENSORBOARDRESPONSE = _descriptor.Descriptor(
  name='CreateTensorboardResponse',
  full_name='grid.v1.CreateTensorboardResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tensorboard', full_name='grid.v1.CreateTensorboardResponse.tensorboard', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='tensorboard', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=265,
  serialized_end=348,
)


_GETTENSORBOARDREQUEST = _descriptor.Descriptor(
  name='GetTensorboardRequest',
  full_name='grid.v1.GetTensorboardRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='grid.v1.GetTensorboardRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='id', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=350,
  serialized_end=389,
)


_GETTENSORBOARDRESPONSE = _descriptor.Descriptor(
  name='GetTensorboardResponse',
  full_name='grid.v1.GetTensorboardResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tensorboard', full_name='grid.v1.GetTensorboardResponse.tensorboard', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='tensorboard', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=391,
  serialized_end=471,
)


_LISTTENSORBOARDSREQUEST = _descriptor.Descriptor(
  name='ListTensorboardsRequest',
  full_name='grid.v1.ListTensorboardsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='continue_token', full_name='grid.v1.ListTensorboardsRequest.continue_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='continueToken', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource_version', full_name='grid.v1.ListTensorboardsRequest.resource_version', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourceVersion', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='grid.v1.ListTensorboardsRequest.limit', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='limit', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_ids', full_name='grid.v1.ListTensorboardsRequest.user_ids', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='userIds', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='grid.v1.ListTensorboardsRequest.cluster_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='clusterId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_before', full_name='grid.v1.ListTensorboardsRequest.created_before', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='createdBefore', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='phase_in', full_name='grid.v1.ListTensorboardsRequest.phase_in', index=6,
      number=7, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='phaseIn', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='phase_not_in', full_name='grid.v1.ListTensorboardsRequest.phase_not_in', index=7,
      number=8, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='phaseNotIn', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=474,
  serialized_end=843,
)


_LISTTENSORBOARDSRESPONSE = _descriptor.Descriptor(
  name='ListTensorboardsResponse',
  full_name='grid.v1.ListTensorboardsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tensorboard', full_name='grid.v1.ListTensorboardsResponse.tensorboard', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='tensorboard', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='continue_token', full_name='grid.v1.ListTensorboardsResponse.continue_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='continueToken', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource_version', full_name='grid.v1.ListTensorboardsResponse.resource_version', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourceVersion', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=846,
  serialized_end=1010,
)


_UPDATETENSORBOARDREQUEST = _descriptor.Descriptor(
  name='UpdateTensorboardRequest',
  full_name='grid.v1.UpdateTensorboardRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tensorboard', full_name='grid.v1.UpdateTensorboardRequest.tensorboard', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='tensorboard', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1012,
  serialized_end=1094,
)


_UPDATETENSORBOARDRESPONSE = _descriptor.Descriptor(
  name='UpdateTensorboardResponse',
  full_name='grid.v1.UpdateTensorboardResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tensorboard', full_name='grid.v1.UpdateTensorboardResponse.tensorboard', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='tensorboard', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1096,
  serialized_end=1179,
)


_UPDATETENSORBOARDSTATUSREQUEST = _descriptor.Descriptor(
  name='UpdateTensorboardStatusRequest',
  full_name='grid.v1.UpdateTensorboardStatusRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tensorboard', full_name='grid.v1.UpdateTensorboardStatusRequest.tensorboard', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='tensorboard', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1181,
  serialized_end=1269,
)


_UPDATETENSORBOARDSTATUSRESPONSE = _descriptor.Descriptor(
  name='UpdateTensorboardStatusResponse',
  full_name='grid.v1.UpdateTensorboardStatusResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tensorboard', full_name='grid.v1.UpdateTensorboardStatusResponse.tensorboard', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='tensorboard', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1271,
  serialized_end=1360,
)


_DELETETENSORBOARDREQUEST = _descriptor.Descriptor(
  name='DeleteTensorboardRequest',
  full_name='grid.v1.DeleteTensorboardRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tensorboard', full_name='grid.v1.DeleteTensorboardRequest.tensorboard', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='tensorboard', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1362,
  serialized_end=1444,
)


_DELETETENSORBOARDRESPONSE = _descriptor.Descriptor(
  name='DeleteTensorboardResponse',
  full_name='grid.v1.DeleteTensorboardResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tensorboard', full_name='grid.v1.DeleteTensorboardResponse.tensorboard', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='tensorboard', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1446,
  serialized_end=1529,
)


_WATCHTENSORBOARDSREQUEST = _descriptor.Descriptor(
  name='WatchTensorboardsRequest',
  full_name='grid.v1.WatchTensorboardsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_version', full_name='grid.v1.WatchTensorboardsRequest.resource_version', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourceVersion', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='grid.v1.WatchTensorboardsRequest.limit', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='limit', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_ids', full_name='grid.v1.WatchTensorboardsRequest.user_ids', index=2,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='userIds', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='grid.v1.WatchTensorboardsRequest.cluster_id', index=3,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='clusterId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_before', full_name='grid.v1.WatchTensorboardsRequest.created_before', index=4,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='createdBefore', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='phase_in', full_name='grid.v1.WatchTensorboardsRequest.phase_in', index=5,
      number=7, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='phaseIn', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='phase_not_in', full_name='grid.v1.WatchTensorboardsRequest.phase_not_in', index=6,
      number=8, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='phaseNotIn', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1532,
  serialized_end=1863,
)


_WATCHTENSORBOARDSRESPONSE = _descriptor.Descriptor(
  name='WatchTensorboardsResponse',
  full_name='grid.v1.WatchTensorboardsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_version', full_name='grid.v1.WatchTensorboardsResponse.resource_version', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourceVersion', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='grid.v1.WatchTensorboardsResponse.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='type', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tensorboard', full_name='grid.v1.WatchTensorboardsResponse.tensorboard', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='tensorboard', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1866,
  serialized_end=2032,
)

_CREATETENSORBOARDREQUEST.fields_by_name['tensorboard'].message_type = grid_dot_v1_dot_tensorboard__pb2._TENSORBOARD
_CREATETENSORBOARDRESPONSE.fields_by_name['tensorboard'].message_type = grid_dot_v1_dot_tensorboard__pb2._TENSORBOARD
_GETTENSORBOARDRESPONSE.fields_by_name['tensorboard'].message_type = grid_dot_v1_dot_tensorboard__pb2._TENSORBOARD
_LISTTENSORBOARDSREQUEST.fields_by_name['created_before'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTTENSORBOARDSREQUEST.fields_by_name['phase_in'].enum_type = grid_dot_v1_dot_tensorboard__pb2._TENSORBOARDSTATE
_LISTTENSORBOARDSREQUEST.fields_by_name['phase_not_in'].enum_type = grid_dot_v1_dot_tensorboard__pb2._TENSORBOARDSTATE
_LISTTENSORBOARDSRESPONSE.fields_by_name['tensorboard'].message_type = grid_dot_v1_dot_tensorboard__pb2._TENSORBOARD
_UPDATETENSORBOARDREQUEST.fields_by_name['tensorboard'].message_type = grid_dot_v1_dot_tensorboard__pb2._TENSORBOARD
_UPDATETENSORBOARDRESPONSE.fields_by_name['tensorboard'].message_type = grid_dot_v1_dot_tensorboard__pb2._TENSORBOARD
_UPDATETENSORBOARDSTATUSREQUEST.fields_by_name['tensorboard'].message_type = grid_dot_v1_dot_tensorboard__pb2._TENSORBOARD
_UPDATETENSORBOARDSTATUSRESPONSE.fields_by_name['tensorboard'].message_type = grid_dot_v1_dot_tensorboard__pb2._TENSORBOARD
_DELETETENSORBOARDREQUEST.fields_by_name['tensorboard'].message_type = grid_dot_v1_dot_tensorboard__pb2._TENSORBOARD
_DELETETENSORBOARDRESPONSE.fields_by_name['tensorboard'].message_type = grid_dot_v1_dot_tensorboard__pb2._TENSORBOARD
_WATCHTENSORBOARDSREQUEST.fields_by_name['created_before'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_WATCHTENSORBOARDSREQUEST.fields_by_name['phase_in'].enum_type = grid_dot_v1_dot_tensorboard__pb2._TENSORBOARDSTATE
_WATCHTENSORBOARDSREQUEST.fields_by_name['phase_not_in'].enum_type = grid_dot_v1_dot_tensorboard__pb2._TENSORBOARDSTATE
_WATCHTENSORBOARDSRESPONSE.fields_by_name['type'].enum_type = grid_dot_v1_dot_event__pb2._EVENTTYPE
_WATCHTENSORBOARDSRESPONSE.fields_by_name['tensorboard'].message_type = grid_dot_v1_dot_tensorboard__pb2._TENSORBOARD
DESCRIPTOR.message_types_by_name['CreateTensorboardRequest'] = _CREATETENSORBOARDREQUEST
DESCRIPTOR.message_types_by_name['CreateTensorboardResponse'] = _CREATETENSORBOARDRESPONSE
DESCRIPTOR.message_types_by_name['GetTensorboardRequest'] = _GETTENSORBOARDREQUEST
DESCRIPTOR.message_types_by_name['GetTensorboardResponse'] = _GETTENSORBOARDRESPONSE
DESCRIPTOR.message_types_by_name['ListTensorboardsRequest'] = _LISTTENSORBOARDSREQUEST
DESCRIPTOR.message_types_by_name['ListTensorboardsResponse'] = _LISTTENSORBOARDSRESPONSE
DESCRIPTOR.message_types_by_name['UpdateTensorboardRequest'] = _UPDATETENSORBOARDREQUEST
DESCRIPTOR.message_types_by_name['UpdateTensorboardResponse'] = _UPDATETENSORBOARDRESPONSE
DESCRIPTOR.message_types_by_name['UpdateTensorboardStatusRequest'] = _UPDATETENSORBOARDSTATUSREQUEST
DESCRIPTOR.message_types_by_name['UpdateTensorboardStatusResponse'] = _UPDATETENSORBOARDSTATUSRESPONSE
DESCRIPTOR.message_types_by_name['DeleteTensorboardRequest'] = _DELETETENSORBOARDREQUEST
DESCRIPTOR.message_types_by_name['DeleteTensorboardResponse'] = _DELETETENSORBOARDRESPONSE
DESCRIPTOR.message_types_by_name['WatchTensorboardsRequest'] = _WATCHTENSORBOARDSREQUEST
DESCRIPTOR.message_types_by_name['WatchTensorboardsResponse'] = _WATCHTENSORBOARDSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CreateTensorboardRequest = _reflection.GeneratedProtocolMessageType('CreateTensorboardRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATETENSORBOARDREQUEST,
  '__module__' : 'grid.v1.tensorboard_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.CreateTensorboardRequest)
  })
_sym_db.RegisterMessage(CreateTensorboardRequest)

CreateTensorboardResponse = _reflection.GeneratedProtocolMessageType('CreateTensorboardResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATETENSORBOARDRESPONSE,
  '__module__' : 'grid.v1.tensorboard_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.CreateTensorboardResponse)
  })
_sym_db.RegisterMessage(CreateTensorboardResponse)

GetTensorboardRequest = _reflection.GeneratedProtocolMessageType('GetTensorboardRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETTENSORBOARDREQUEST,
  '__module__' : 'grid.v1.tensorboard_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.GetTensorboardRequest)
  })
_sym_db.RegisterMessage(GetTensorboardRequest)

GetTensorboardResponse = _reflection.GeneratedProtocolMessageType('GetTensorboardResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETTENSORBOARDRESPONSE,
  '__module__' : 'grid.v1.tensorboard_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.GetTensorboardResponse)
  })
_sym_db.RegisterMessage(GetTensorboardResponse)

ListTensorboardsRequest = _reflection.GeneratedProtocolMessageType('ListTensorboardsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTTENSORBOARDSREQUEST,
  '__module__' : 'grid.v1.tensorboard_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.ListTensorboardsRequest)
  })
_sym_db.RegisterMessage(ListTensorboardsRequest)

ListTensorboardsResponse = _reflection.GeneratedProtocolMessageType('ListTensorboardsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTTENSORBOARDSRESPONSE,
  '__module__' : 'grid.v1.tensorboard_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.ListTensorboardsResponse)
  })
_sym_db.RegisterMessage(ListTensorboardsResponse)

UpdateTensorboardRequest = _reflection.GeneratedProtocolMessageType('UpdateTensorboardRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATETENSORBOARDREQUEST,
  '__module__' : 'grid.v1.tensorboard_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.UpdateTensorboardRequest)
  })
_sym_db.RegisterMessage(UpdateTensorboardRequest)

UpdateTensorboardResponse = _reflection.GeneratedProtocolMessageType('UpdateTensorboardResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATETENSORBOARDRESPONSE,
  '__module__' : 'grid.v1.tensorboard_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.UpdateTensorboardResponse)
  })
_sym_db.RegisterMessage(UpdateTensorboardResponse)

UpdateTensorboardStatusRequest = _reflection.GeneratedProtocolMessageType('UpdateTensorboardStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATETENSORBOARDSTATUSREQUEST,
  '__module__' : 'grid.v1.tensorboard_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.UpdateTensorboardStatusRequest)
  })
_sym_db.RegisterMessage(UpdateTensorboardStatusRequest)

UpdateTensorboardStatusResponse = _reflection.GeneratedProtocolMessageType('UpdateTensorboardStatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATETENSORBOARDSTATUSRESPONSE,
  '__module__' : 'grid.v1.tensorboard_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.UpdateTensorboardStatusResponse)
  })
_sym_db.RegisterMessage(UpdateTensorboardStatusResponse)

DeleteTensorboardRequest = _reflection.GeneratedProtocolMessageType('DeleteTensorboardRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETETENSORBOARDREQUEST,
  '__module__' : 'grid.v1.tensorboard_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.DeleteTensorboardRequest)
  })
_sym_db.RegisterMessage(DeleteTensorboardRequest)

DeleteTensorboardResponse = _reflection.GeneratedProtocolMessageType('DeleteTensorboardResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETETENSORBOARDRESPONSE,
  '__module__' : 'grid.v1.tensorboard_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.DeleteTensorboardResponse)
  })
_sym_db.RegisterMessage(DeleteTensorboardResponse)

WatchTensorboardsRequest = _reflection.GeneratedProtocolMessageType('WatchTensorboardsRequest', (_message.Message,), {
  'DESCRIPTOR' : _WATCHTENSORBOARDSREQUEST,
  '__module__' : 'grid.v1.tensorboard_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.WatchTensorboardsRequest)
  })
_sym_db.RegisterMessage(WatchTensorboardsRequest)

WatchTensorboardsResponse = _reflection.GeneratedProtocolMessageType('WatchTensorboardsResponse', (_message.Message,), {
  'DESCRIPTOR' : _WATCHTENSORBOARDSRESPONSE,
  '__module__' : 'grid.v1.tensorboard_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.WatchTensorboardsResponse)
  })
_sym_db.RegisterMessage(WatchTensorboardsResponse)


DESCRIPTOR._options = None

_TENSORBOARDSERVICE = _descriptor.ServiceDescriptor(
  name='TensorboardService',
  full_name='grid.v1.TensorboardService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=2035,
  serialized_end=2927,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreateTensorboard',
    full_name='grid.v1.TensorboardService.CreateTensorboard',
    index=0,
    containing_service=None,
    input_type=_CREATETENSORBOARDREQUEST,
    output_type=_CREATETENSORBOARDRESPONSE,
    serialized_options=b'\202\323\344\223\002\032\"\025/v1/core/tensorboards:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetTensorboard',
    full_name='grid.v1.TensorboardService.GetTensorboard',
    index=1,
    containing_service=None,
    input_type=_GETTENSORBOARDREQUEST,
    output_type=_GETTENSORBOARDRESPONSE,
    serialized_options=b'\202\323\344\223\002\034\022\032/v1/core/tensorboards/{id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListTensorboards',
    full_name='grid.v1.TensorboardService.ListTensorboards',
    index=2,
    containing_service=None,
    input_type=_LISTTENSORBOARDSREQUEST,
    output_type=_LISTTENSORBOARDSRESPONSE,
    serialized_options=b'\202\323\344\223\002\027\022\025/v1/core/tensorboards',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateTensorboard',
    full_name='grid.v1.TensorboardService.UpdateTensorboard',
    index=3,
    containing_service=None,
    input_type=_UPDATETENSORBOARDREQUEST,
    output_type=_UPDATETENSORBOARDRESPONSE,
    serialized_options=b'\202\323\344\223\0024\032//v1/core/tensorboards/{tensorboard.metadata.id}:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateTensorboardStatus',
    full_name='grid.v1.TensorboardService.UpdateTensorboardStatus',
    index=4,
    containing_service=None,
    input_type=_UPDATETENSORBOARDSTATUSREQUEST,
    output_type=_UPDATETENSORBOARDSTATUSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteTensorboard',
    full_name='grid.v1.TensorboardService.DeleteTensorboard',
    index=5,
    containing_service=None,
    input_type=_DELETETENSORBOARDREQUEST,
    output_type=_DELETETENSORBOARDRESPONSE,
    serialized_options=b'\202\323\344\223\0021*//v1/core/tensorboards/{tensorboard.metadata.id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='WatchTensorboards',
    full_name='grid.v1.TensorboardService.WatchTensorboards',
    index=6,
    containing_service=None,
    input_type=_WATCHTENSORBOARDSREQUEST,
    output_type=_WATCHTENSORBOARDSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_TENSORBOARDSERVICE)

DESCRIPTOR.services_by_name['TensorboardService'] = _TENSORBOARDSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grid/v1/image.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from grid.protos.grid.v1 import metadata_pb2 as grid_dot_v1_dot_metadata__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='grid/v1/image.proto',
  package='grid.v1',
  syntax='proto3',
  serialized_options=b'Z0github.com/gridai/grid/grid-backend/apis/grid/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x13grid/v1/image.proto\x12\x07grid.v1\x1a\x16grid/v1/metadata.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x19google/protobuf/any.proto\"j\n\x12\x44\x65pendencyFileInfo\x12@\n\x0fpackage_manager\x18\x01 \x01(\x0e\x32\x17.grid.v1.PackageManagerR\x0epackageManager\x12\x12\n\x04path\x18\x02 \x01(\tR\x04path\"\xe0\x01\n\tImageSpec\x12\x16\n\x05image\x18\x01 \x01(\tH\x00R\x05image\x12 \n\ndockerfile\x18\x02 \x01(\tH\x00R\ndockerfile\x12\x35\n\x17on_image_build_commands\x18\x03 \x03(\tR\x14onImageBuildCommands\x12M\n\x14\x64\x65pendency_file_info\x18\x04 \x01(\x0b\x32\x1b.grid.v1.DependencyFileInfoR\x12\x64\x65pendencyFileInfoB\x13\n\x11\x62\x61se_image_source*e\n\x0ePackageManager\x12\x1f\n\x1bPACKAGE_MANAGER_UNSPECIFIED\x10\x00\x12\x17\n\x13PACKAGE_MANAGER_PIP\x10\x01\x12\x19\n\x15PACKAGE_MANAGER_CONDA\x10\x02\x42\x32Z0github.com/gridai/grid/grid-backend/apis/grid/v1b\x06proto3'
  ,
  dependencies=[grid_dot_v1_dot_metadata__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_protobuf_dot_any__pb2.DESCRIPTOR,])

_PACKAGEMANAGER = _descriptor.EnumDescriptor(
  name='PackageManager',
  full_name='grid.v1.PackageManager',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PACKAGE_MANAGER_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PACKAGE_MANAGER_PIP', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PACKAGE_MANAGER_CONDA', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=451,
  serialized_end=552,
)
_sym_db.RegisterEnumDescriptor(_PACKAGEMANAGER)

PackageManager = enum_type_wrapper.EnumTypeWrapper(_PACKAGEMANAGER)
PACKAGE_MANAGER_UNSPECIFIED = 0
PACKAGE_MANAGER_PIP = 1
PACKAGE_MANAGER_CONDA = 2



_DEPENDENCYFILEINFO = _descriptor.Descriptor(
  name='DependencyFileInfo',
  full_name='grid.v1.DependencyFileInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='package_manager', full_name='grid.v1.DependencyFileInfo.package_manager', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='packageManager', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='grid.v1.DependencyFileInfo.path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='path', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=116,
  serialized_end=222,
)


_IMAGESPEC = _descriptor.Descriptor(
  name='ImageSpec',
  full_name='grid.v1.ImageSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='image', full_name='grid.v1.ImageSpec.image', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='image', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dockerfile', full_name='grid.v1.ImageSpec.dockerfile', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='dockerfile', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='on_image_build_commands', full_name='grid.v1.ImageSpec.on_image_build_commands', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='onImageBuildCommands', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dependency_file_info', full_name='grid.v1.ImageSpec.dependency_file_info', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='dependencyFileInfo', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='base_image_source', full_name='grid.v1.ImageSpec.base_image_source',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=225,
  serialized_end=449,
)

_DEPENDENCYFILEINFO.fields_by_name['package_manager'].enum_type = _PACKAGEMANAGER
_IMAGESPEC.fields_by_name['dependency_file_info'].message_type = _DEPENDENCYFILEINFO
_IMAGESPEC.oneofs_by_name['base_image_source'].fields.append(
  _IMAGESPEC.fields_by_name['image'])
_IMAGESPEC.fields_by_name['image'].containing_oneof = _IMAGESPEC.oneofs_by_name['base_image_source']
_IMAGESPEC.oneofs_by_name['base_image_source'].fields.append(
  _IMAGESPEC.fields_by_name['dockerfile'])
_IMAGESPEC.fields_by_name['dockerfile'].containing_oneof = _IMAGESPEC.oneofs_by_name['base_image_source']
DESCRIPTOR.message_types_by_name['DependencyFileInfo'] = _DEPENDENCYFILEINFO
DESCRIPTOR.message_types_by_name['ImageSpec'] = _IMAGESPEC
DESCRIPTOR.enum_types_by_name['PackageManager'] = _PACKAGEMANAGER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DependencyFileInfo = _reflection.GeneratedProtocolMessageType('DependencyFileInfo', (_message.Message,), {
  'DESCRIPTOR' : _DEPENDENCYFILEINFO,
  '__module__' : 'grid.v1.image_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.DependencyFileInfo)
  })
_sym_db.RegisterMessage(DependencyFileInfo)

ImageSpec = _reflection.GeneratedProtocolMessageType('ImageSpec', (_message.Message,), {
  'DESCRIPTOR' : _IMAGESPEC,
  '__module__' : 'grid.v1.image_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.ImageSpec)
  })
_sym_db.RegisterMessage(ImageSpec)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



from dataclasses import dataclass, field
from enum import Enum
import json
import logging
import math
import os
from pathlib import Path
import shutil
from threading import Lock
from typing import Dict, List, Optional
import uuid

from click import ClickException
from dataclasses_json import dataclass_json
import requests
import yaspin

import grid.cli.globals as env
from grid.openapi import Body2, Body3, DatastoreServiceApi, V1CompletePresignedUrlUpload
from grid.sdk._gql.queries import complete_datastore_upload, create_datastore
from grid.sdk.client import create_swagger_client
from grid.sdk.utils.tar import get_split_size, tar_path
from grid.sdk.utils.uploader import S3Uploader, UploadProgressCallback

SUPPORTED_FILE_EXTENSIONS = [".zip", ".tar", ".tar.gz"]


def clear_cache():
    session_path = Path.home().joinpath(DatastoreUploadSession.grid_datastores_path)
    if session_path.exists():
        shutil.rmtree(str(session_path))


def find_supported_extension(path_or_url: str) -> Optional[str]:
    """Returns the supported extension if exists"""
    for extension in SUPPORTED_FILE_EXTENSIONS:
        if path_or_url.endswith(extension):
            return extension

    return None


def check_source(source: str):
    """
    Check if the source is a valid source for datastore
    """
    if source.startswith("s3://"):
        return

    if source.startswith("http"):
        if not find_supported_extension(source):
            raise ClickException(
                f"""
                Grid currently only supports remote files with the
                following extensions: {SUPPORTED_FILE_EXTENSIONS}
                """
            )

        # Check if url is accessible
        status = requests.head(source, allow_redirects=True)
        if status.status_code != 200:
            raise ClickException(f"Source url {source} is not reachable")
        return

    source_path = Path(source)
    if source_path.exists() is False:
        raise ClickException(f"Source local path {source} doesn't exist")

    if source_path.is_file():
        if not find_supported_extension(source):
            raise ClickException(
                f"""
                Grid currently only supports local file upload with the
                following extensions: {SUPPORTED_FILE_EXTENSIONS}
                """
            )
        return

    if not source_path.is_dir():
        raise ClickException(
            f"""
             Grid currently only supports local sources that are either
             a compressed file or directory.
        """
        )


def create_datastore_session(name: str, source: str, compression: bool, cluster: Optional[str] = None):
    """Creates datastore session based on source"""
    check_source(source)
    if cluster is None:
        if env.CONTEXT is None:
            raise RuntimeError(
                "Cluster not found! Try logging in again. If the problem persist, "
                "reach out to support@grid.ai"
            )
        cluster = env.CONTEXT
    if source.startswith("http") or source.startswith("s3://"):
        return DatastoreRemoteUpload(name=name, source_url=source, cluster=cluster)

    s = DatastoreUploadSession(name=name, source_dir=source, compression=compression, cluster_id=cluster)
    s.configure()
    return s


class InvalidDatastoreError(Exception):
    """Error that is non-recoverable when uploading datastore"""


class UnsupportedDatastoreImplementationError(Exception):
    """Error when trying to recover a non-supported datastore implementation"""


class DatastoreUploadSteps(str, Enum):
    CREATE_DATASTORE = "create_datastore"
    GET_PRESIGNED_URLS = "get_presigned_urls"
    COMPRESS_SOURCE_DIRECTORY = "compress_source_directory"
    UPLOAD_PARTS = "upload_parts"
    MARK_UPLOAD_COMPLETE = "mark_upload_complete"


def create_datastore_api_client() -> DatastoreServiceApi:
    api_client = create_swagger_client()
    return DatastoreServiceApi(api_client)


class DatastoreRemoteUpload:
    """
    This class handles creating a datastore in Grid.

    Attributes
    ----------
    name: str
        Name of the datastore
    source_url: str
        Source data url
    """
    def __init__(self, name: str, source_url: str, cluster: Optional[str] = None):
        self.name = name
        self.source_url = source_url
        self.logger = logging.getLogger("grid.sdk.utils.datastore_uploader")
        self.cluster = cluster

    def upload(self):
        spinner = yaspin.yaspin(text=f'Creating datastore {self.name}', color="yellow")
        spinner.start()

        try:
            create_datastore(
                name=self.name,
                source=self.source_url,
                cluster=self.cluster,
            )
        except Exception as e:
            spinner.text = "Failed to create datastore"
            spinner.fail("✘")
            raise e

        spinner.text = "Finished creating datastore"
        spinner.ok("✔")


@dataclass_json
@dataclass
class DatastoreUploadSession(UploadProgressCallback):
    """This class handles uploading datastore

    Attributes
    ----------
    name: str
        Name of the datastore
    source_dir: str
        Source directory to upload from
    presigned_urls: Dict[int, str]
        Presigned urls retrieved from backend
    etags: Dict[int, str]
        Etags per part after uploading to cloud
    session_path: str
        Path to session files (data and state file)
    session_state_file: str
        Path to session state file
    """
    # This version is a datastore implementation version. If we change this
    # version means we no longer able to recover sessions that is not the same
    # version. This is assuming to be fine as datastore upload recovering
    # should be a optimization.
    DATASTORE_VERSION = 2
    # Path storing datastore session and compressed data
    grid_datastores_path = '.grid/datastores'

    # Datastore upload fields
    name: str
    source_dir: str

    version: int = 1
    id: str = ""
    upload_id: str = ""
    original_size: int = 0
    compressed_size: int = 0
    part_count: int = 0

    # Session state
    session_id: str = ""
    session_path: str = ""
    session_state_file: str = ""
    last_completed_step: DatastoreUploadSteps = None

    presigned_urls: Dict[int, str] = field(default_factory=dict)
    etags: Dict[int, str] = field(default_factory=dict)

    # Compression
    compression: bool = False

    cluster_id: Optional[str] = None

    def configure(self):
        self.lock = Lock()
        self.logger = logging.getLogger("uploader.DatastoreUploadSession")
        self.spinner = None

    @staticmethod
    def recover_sessions() -> List['DatastoreUploadSession']:
        """Recover all upload sessions that wasn't completed, so user can resume them.

        Returns
        -------
        List[DatastoreUploadSession]
            List of resumable sessions
        """
        logger = logging.getLogger("DatastoreUploadSession")
        sessions = []
        session_path = str(Path.home().joinpath(DatastoreUploadSession.grid_datastores_path))
        session_dirs = os.listdir(session_path)
        for session_dir in session_dirs:
            session_dir = os.path.join(session_path, session_dir)
            try:
                session = DatastoreUploadSession.recover(session_dir)
                last_completed_step = session.last_completed_step
                if last_completed_step in [None, DatastoreUploadSteps.COMPRESS_SOURCE_DIRECTORY]:
                    # We choose not to resume sessions that hasn't finished getting
                    # presigned_urls, since the datastore version is only determined
                    # when that's called, and we don't know what version we're going
                    # to be resuming.
                    raise ValueError("Session not yet finished compression")

                sessions.append(session)
            except (ValueError, UnsupportedDatastoreImplementationError) as e:
                logger.warning(f"Removing incomplete session {session_dir}, reason: {e}")
                shutil.rmtree(session_dir, ignore_errors=True)

        return sessions

    @staticmethod
    def recover(session_dir: str) -> "DatastoreUploadSession":
        """Recover session if sessions exists
        """
        session_state_file = os.path.join(session_dir, "session.json")
        if not os.path.exists(session_state_file):
            raise ValueError("Session state file does not exist")

        with open(session_state_file, "r") as f:
            content = json.load(f)
            datastore_version = 0
            if "DATASTORE_VERSION" in content:
                datastore_version = content["DATASTORE_VERSION"]
            if datastore_version != DatastoreUploadSession.DATASTORE_VERSION:
                name = content["name"]
                version = content["version"]
                session_name = f"{name}-v{version}"
                raise UnsupportedDatastoreImplementationError(
                    f"Incomplete datastore session {session_name} is no " +
                    "longer supported. Please restart this upload."
                )

            session = DatastoreUploadSession.from_dict(content)

        return session

    def _update_progress(self, text: str):
        """Update current progress

        Parameters
        ----------
        text: str
            Latest progress text
        """
        if self.spinner:
            self.spinner.text = text

    def _get_presigned_urls(self):
        """Gets presigned urls from backend
        """
        if self.part_count <= 0:
            raise InvalidDatastoreError(f"Invalid part count calculated for datastore: {self.part_count}")

        self._update_progress("Requesting presigned URLs from Grid...")

        object_key = f"datastores/{self.id}/data/{self.uploaded_target_file}"

        api_client = create_datastore_api_client()
        response = api_client.datastore_service_create_datastore_presigned_urls(
            cluster_id=self.cluster_id, datastore_id=self.id, body=Body2(count=self.part_count, object_key=object_key)
        )

        self.upload_id = response.upload_id
        presigned_map = {}
        for url in response.urls:
            presigned_map[int(url.part_number)] = url.url

        self.presigned_urls = presigned_map

    @property
    def target_file(self) -> str:
        """Get target compressed data file"""
        source_path = Path(self.source_dir)
        if source_path.is_dir():
            return os.path.join(self.session_path, "data.tar.gz")
        else:
            return self.source_dir

    @property
    def uploaded_target_file(self) -> str:
        """The target file name we will upload into S3"""
        source_path = Path(self.source_dir)
        if source_path.is_dir():
            # Since we're compressing the directory ourselves, we know the file name is ending with .tar.gz
            return "data.tar.gz"
        else:
            extension = find_supported_extension(self.source_dir)
            return f"data{extension}"

    def _create_datastore(self):
        self._update_progress("Creating datastore in Grid...")
        datastore_data = create_datastore(name=self.name, source=self.uploaded_target_file, cluster=self.cluster_id)
        self.id = datastore_data['datastoreId']
        self.version = datastore_data['datastoreVersion']

    def _compress_source(self):
        source_path = Path(self.source_dir)
        if source_path.is_file():
            # We assume we already checked that the file is a compressed archive. Skip compressing
            # We don't know the uncompressed size, so leaving it None so we can compute it online.
            self.original_size = 0
            self.compressed_size = source_path.stat().st_size
            split_size = get_split_size(self.compressed_size)
            self.part_count = math.ceil(self.compressed_size / split_size)
            return

        # Source is a directory, compress it into a tar file.
        if self.compression:
            self._update_progress(f"Packaging and compressing datastore {self.name}...")
        else:
            self._update_progress(f"Packaging datastore {self.name}...")

        tar_results = tar_path(source_path=self.source_dir, target_file=self.target_file, compression=self.compression)

        self.original_size = tar_results.before_size
        self.compressed_size = tar_results.after_size
        split_size = get_split_size(self.compressed_size)
        self.part_count = math.ceil(self.compressed_size / split_size)

    def _create_uploader(self, presigned_urls: Dict[int, str], already_uploaded_parts: List[int]):
        # We added compressed size later, so if a session didn't have it serialized we will
        # look it up. This is used for the progress bar only and not affect functionality.
        size = self.compressed_size
        if size == 0:
            size = os.stat(self.target_file).st_size
        split_size = get_split_size(size)

        return S3Uploader(
            source_file=self.target_file,
            presigned_urls=presigned_urls,
            already_uploaded_parts=already_uploaded_parts,
            name=f"{self.name}-{self.version}",
            split_size=split_size,
            total_size=size,
            progress_callback=self
        )

    def _upload_parts(self):
        self._update_progress(f"Uploading datastore {self.name} (v{self.version}) datastore" + " to S3...")

        # Split urls depending on whether they were already uploaded or not.
        # This can happen if we resume an upload session.
        # The already uploaded ones are useful to show an accurate progress percentage.
        unuploaded_presigned_urls, already_uploaded_parts = {}, []
        for part, url in self.presigned_urls.items():
            if part not in self.etags:
                unuploaded_presigned_urls[part] = url
            else:
                already_uploaded_parts.append(part)
        uploader = self._create_uploader(
            presigned_urls=unuploaded_presigned_urls, already_uploaded_parts=already_uploaded_parts
        )

        # Stopping and starting the spinner, as the progress bar
        # in uploader will conflict with the spinner
        if self.spinner:
            self.spinner.stop()

        uploader.upload()

        if self.spinner:
            self.spinner.start()

    def _mark_upload_complete(self):
        self._update_progress("Completing multi-part uploads with Grid...")

        key = f"datastores/{self.id}/data/{self.uploaded_target_file}"
        urls = []
        for part, etag in self.etags.items():
            urls.append(V1CompletePresignedUrlUpload(etag=etag, part_number=int(part)))

        api_client = create_datastore_api_client()
        api_client.datastore_service_complete_datastore_presigned_urls_upload(
            datastore_id=self.id,
            upload_id=self.upload_id,
            cluster_id=self.cluster_id,
            body=Body3(object_key=key, urls=urls)
        )

        self._update_progress("Completing datastore upload...")
        size_mib = math.ceil(self.original_size / (1024**2))
        # TODO - move to external API
        complete_datastore_upload(datastore_id=self.id, size_mib=size_mib)

    def _create_session_file(self, session_id: str):
        """Create session state file so we can resume upload progress.
        """
        self.session_path = os.path.join(self.grid_datastores_path, session_id)
        self.session_path = str(Path.home().joinpath(self.session_path))
        Path.home().joinpath(self.session_path).mkdir(parents=True, exist_ok=True)
        self.session_file = os.path.join(self.session_path, "session.json")

    @property
    def session_name(self) -> str:
        return f"{self.name}-v{self.version}"

    def upload(self):
        """Upload completes the full datastore upload operation.

        It also records the progress of the upload, so it can be resumed later.
        """
        if self.session_id == "":
            self.session_id = str(uuid.uuid4())

        self._create_session_file(self.session_id)

        self.spinner = yaspin.yaspin(text=f'Uploading datastore {self.name} v{self.version}', color="yellow")
        self.spinner.start()

        steps = [(self._create_datastore, DatastoreUploadSteps.CREATE_DATASTORE),
                 (self._compress_source, DatastoreUploadSteps.COMPRESS_SOURCE_DIRECTORY),
                 (self._get_presigned_urls, DatastoreUploadSteps.GET_PRESIGNED_URLS),
                 (self._upload_parts, DatastoreUploadSteps.UPLOAD_PARTS),
                 (self._mark_upload_complete, DatastoreUploadSteps.MARK_UPLOAD_COMPLETE)]

        current_step = 0
        if self.last_completed_step:
            for i, step in enumerate(steps):
                if step[1] == self.last_completed_step:
                    current_step = i + 1
                    break

            if current_step == 0:
                raise ValueError(f"Unsupported upload step: " + self.last_completed_step)

        try:
            while current_step < len(steps):
                func, step = steps[current_step]
                func()
                self.last_completed_step = step
                self._write_session()
                current_step += 1

            self._remove_session()

            self.spinner.text = "Finished uploading datastore."
            self.spinner.ok("✔")

        except InvalidDatastoreError as e:
            self.spinner.fail("✘")
            self.logger.error(
                f"""
            An non-recoverable error occured when uploading datastore
            {self.session_name}.

            Please try again or contact Grid for support
            """
            )
            raise e
        except (Exception, KeyboardInterrupt) as e:
            self.spinner.fail("✘")
            message = f"""
            Whoops, your datastore creation failed!

            To resume, run:

            grid datastore resume {self.session_name}
            """
            self.logger.error(message)
            raise e
        finally:
            self.spinner.stop()

    def upload_part_completed(self, part: int, etag: str):
        """Mark part uploaded

        Parameters
        ----------
        part: int
            Part number
        etag: str
            ETag returned
        """
        self.logger.debug(f"Part {part} finished uploading")
        with self.lock:
            self.etags[part] = etag
            self._write_session()

    def _write_session(self):
        """Writes the session state into session file
        """
        with open(self.session_file, "w") as f:
            data = self.to_dict()
            data["DATASTORE_VERSION"] = self.DATASTORE_VERSION
            json.dump(data, f)

    def _remove_session(self):
        shutil.rmtree(self.session_path, ignore_errors=True)



# coding: utf-8

"""
    external/v1/external_session_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from grid.openapi.configuration import Configuration


class V1ClusterSpec(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'cluster_type': 'V1ClusterType',
        'cost_factor': 'str',
        'desired_state': 'V1ClusterState',
        'driver': 'V1ClusterDriver',
        'gridlet_version': 'str',
        'internal': 'bool',
        'padding_factor': 'str',
        'pause_automation': 'bool',
        'performance_profile': 'V1ClusterPerformanceProfile',
        'user_id': 'str'
    }

    attribute_map = {
        'cluster_type': 'clusterType',
        'cost_factor': 'costFactor',
        'desired_state': 'desiredState',
        'driver': 'driver',
        'gridlet_version': 'gridletVersion',
        'internal': 'internal',
        'padding_factor': 'paddingFactor',
        'pause_automation': 'pauseAutomation',
        'performance_profile': 'performanceProfile',
        'user_id': 'userId'
    }

    def __init__(self, cluster_type=None, cost_factor=None, desired_state=None, driver=None, gridlet_version=None, internal=None, padding_factor=None, pause_automation=None, performance_profile=None, user_id=None, _configuration=None):  # noqa: E501
        """V1ClusterSpec - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._cluster_type = None
        self._cost_factor = None
        self._desired_state = None
        self._driver = None
        self._gridlet_version = None
        self._internal = None
        self._padding_factor = None
        self._pause_automation = None
        self._performance_profile = None
        self._user_id = None
        self.discriminator = None

        if cluster_type is not None:
            self.cluster_type = cluster_type
        if cost_factor is not None:
            self.cost_factor = cost_factor
        if desired_state is not None:
            self.desired_state = desired_state
        if driver is not None:
            self.driver = driver
        if gridlet_version is not None:
            self.gridlet_version = gridlet_version
        if internal is not None:
            self.internal = internal
        if padding_factor is not None:
            self.padding_factor = padding_factor
        if pause_automation is not None:
            self.pause_automation = pause_automation
        if performance_profile is not None:
            self.performance_profile = performance_profile
        if user_id is not None:
            self.user_id = user_id

    @property
    def cluster_type(self):
        """Gets the cluster_type of this V1ClusterSpec.  # noqa: E501


        :return: The cluster_type of this V1ClusterSpec.  # noqa: E501
        :rtype: V1ClusterType
        """
        return self._cluster_type

    @cluster_type.setter
    def cluster_type(self, cluster_type):
        """Sets the cluster_type of this V1ClusterSpec.


        :param cluster_type: The cluster_type of this V1ClusterSpec.  # noqa: E501
        :type: V1ClusterType
        """

        self._cluster_type = cluster_type

    @property
    def cost_factor(self):
        """Gets the cost_factor of this V1ClusterSpec.  # noqa: E501


        :return: The cost_factor of this V1ClusterSpec.  # noqa: E501
        :rtype: str
        """
        return self._cost_factor

    @cost_factor.setter
    def cost_factor(self, cost_factor):
        """Sets the cost_factor of this V1ClusterSpec.


        :param cost_factor: The cost_factor of this V1ClusterSpec.  # noqa: E501
        :type: str
        """

        self._cost_factor = cost_factor

    @property
    def desired_state(self):
        """Gets the desired_state of this V1ClusterSpec.  # noqa: E501


        :return: The desired_state of this V1ClusterSpec.  # noqa: E501
        :rtype: V1ClusterState
        """
        return self._desired_state

    @desired_state.setter
    def desired_state(self, desired_state):
        """Sets the desired_state of this V1ClusterSpec.


        :param desired_state: The desired_state of this V1ClusterSpec.  # noqa: E501
        :type: V1ClusterState
        """

        self._desired_state = desired_state

    @property
    def driver(self):
        """Gets the driver of this V1ClusterSpec.  # noqa: E501


        :return: The driver of this V1ClusterSpec.  # noqa: E501
        :rtype: V1ClusterDriver
        """
        return self._driver

    @driver.setter
    def driver(self, driver):
        """Sets the driver of this V1ClusterSpec.


        :param driver: The driver of this V1ClusterSpec.  # noqa: E501
        :type: V1ClusterDriver
        """

        self._driver = driver

    @property
    def gridlet_version(self):
        """Gets the gridlet_version of this V1ClusterSpec.  # noqa: E501


        :return: The gridlet_version of this V1ClusterSpec.  # noqa: E501
        :rtype: str
        """
        return self._gridlet_version

    @gridlet_version.setter
    def gridlet_version(self, gridlet_version):
        """Sets the gridlet_version of this V1ClusterSpec.


        :param gridlet_version: The gridlet_version of this V1ClusterSpec.  # noqa: E501
        :type: str
        """

        self._gridlet_version = gridlet_version

    @property
    def internal(self):
        """Gets the internal of this V1ClusterSpec.  # noqa: E501


        :return: The internal of this V1ClusterSpec.  # noqa: E501
        :rtype: bool
        """
        return self._internal

    @internal.setter
    def internal(self, internal):
        """Sets the internal of this V1ClusterSpec.


        :param internal: The internal of this V1ClusterSpec.  # noqa: E501
        :type: bool
        """

        self._internal = internal

    @property
    def padding_factor(self):
        """Gets the padding_factor of this V1ClusterSpec.  # noqa: E501


        :return: The padding_factor of this V1ClusterSpec.  # noqa: E501
        :rtype: str
        """
        return self._padding_factor

    @padding_factor.setter
    def padding_factor(self, padding_factor):
        """Sets the padding_factor of this V1ClusterSpec.


        :param padding_factor: The padding_factor of this V1ClusterSpec.  # noqa: E501
        :type: str
        """

        self._padding_factor = padding_factor

    @property
    def pause_automation(self):
        """Gets the pause_automation of this V1ClusterSpec.  # noqa: E501


        :return: The pause_automation of this V1ClusterSpec.  # noqa: E501
        :rtype: bool
        """
        return self._pause_automation

    @pause_automation.setter
    def pause_automation(self, pause_automation):
        """Sets the pause_automation of this V1ClusterSpec.


        :param pause_automation: The pause_automation of this V1ClusterSpec.  # noqa: E501
        :type: bool
        """

        self._pause_automation = pause_automation

    @property
    def performance_profile(self):
        """Gets the performance_profile of this V1ClusterSpec.  # noqa: E501


        :return: The performance_profile of this V1ClusterSpec.  # noqa: E501
        :rtype: V1ClusterPerformanceProfile
        """
        return self._performance_profile

    @performance_profile.setter
    def performance_profile(self, performance_profile):
        """Sets the performance_profile of this V1ClusterSpec.


        :param performance_profile: The performance_profile of this V1ClusterSpec.  # noqa: E501
        :type: V1ClusterPerformanceProfile
        """

        self._performance_profile = performance_profile

    @property
    def user_id(self):
        """Gets the user_id of this V1ClusterSpec.  # noqa: E501


        :return: The user_id of this V1ClusterSpec.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this V1ClusterSpec.


        :param user_id: The user_id of this V1ClusterSpec.  # noqa: E501
        :type: str
        """

        self._user_id = user_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1ClusterSpec, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1ClusterSpec):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, V1ClusterSpec):
            return True

        return self.to_dict() != other.to_dict()



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grid/v1/event_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from grid.protos.grid.v1 import event_pb2 as grid_dot_v1_dot_event__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='grid/v1/event_service.proto',
  package='grid.v1',
  syntax='proto3',
  serialized_options=b'Z0github.com/gridai/grid/grid-backend/apis/grid/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1bgrid/v1/event_service.proto\x12\x07grid.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x19google/protobuf/any.proto\x1a\x13grid/v1/event.proto\"\xd5\x01\n\x0b\x45ventFilter\x12\x17\n\x07user_id\x18\x01 \x01(\tR\x06userId\x12:\n\rresource_type\x18\x02 \x01(\x0e\x32\x15.grid.v1.ResourceTypeR\x0cresourceType\x12\x31\n\nevent_type\x18\x03 \x01(\x0e\x32\x12.grid.v1.EventTypeR\teventType\x12\x1f\n\x0bresource_id\x18\x04 \x01(\tR\nresourceId\x12\x1d\n\ncluster_id\x18\x05 \x01(\tR\tclusterId\"\xd9\x01\n\x10GetEventsRequest\x12,\n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x14.grid.v1.EventFilterR\x06\x66ilter\x12.\n\x04\x66rom\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x04\x66rom\x12*\n\x02to\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x02to\x12%\n\x0e\x63ontinue_token\x18\x04 \x01(\tR\rcontinueToken\x12\x14\n\x05limit\x18\x05 \x01(\x03R\x05limit\"b\n\x11GetEventsResponse\x12&\n\x06\x65vents\x18\x01 \x03(\x0b\x32\x0e.grid.v1.EventR\x06\x65vents\x12%\n\x0e\x63ontinue_token\x18\x02 \x01(\tR\rcontinueToken\"B\n\x12WatchEventsRequest\x12,\n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x14.grid.v1.EventFilterR\x06\x66ilter\"=\n\x13WatchEventsResponse\x12&\n\x06\x65vents\x18\x01 \x03(\x0b\x32\x0e.grid.v1.EventR\x06\x65vents2\x9e\x01\n\x0c\x45ventService\x12\x42\n\tGetEvents\x12\x19.grid.v1.GetEventsRequest\x1a\x1a.grid.v1.GetEventsResponse\x12J\n\x0bWatchEvents\x12\x1b.grid.v1.WatchEventsRequest\x1a\x1c.grid.v1.WatchEventsResponse0\x01\x42\x32Z0github.com/gridai/grid/grid-backend/apis/grid/v1b\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_protobuf_dot_any__pb2.DESCRIPTOR,grid_dot_v1_dot_event__pb2.DESCRIPTOR,])




_EVENTFILTER = _descriptor.Descriptor(
  name='EventFilter',
  full_name='grid.v1.EventFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_id', full_name='grid.v1.EventFilter.user_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='userId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource_type', full_name='grid.v1.EventFilter.resource_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourceType', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='event_type', full_name='grid.v1.EventFilter.event_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='eventType', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource_id', full_name='grid.v1.EventFilter.resource_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourceId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='grid.v1.EventFilter.cluster_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='clusterId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=122,
  serialized_end=335,
)


_GETEVENTSREQUEST = _descriptor.Descriptor(
  name='GetEventsRequest',
  full_name='grid.v1.GetEventsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='filter', full_name='grid.v1.GetEventsRequest.filter', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='filter', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='from', full_name='grid.v1.GetEventsRequest.from', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='from', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='to', full_name='grid.v1.GetEventsRequest.to', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='to', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='continue_token', full_name='grid.v1.GetEventsRequest.continue_token', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='continueToken', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='grid.v1.GetEventsRequest.limit', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='limit', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=338,
  serialized_end=555,
)


_GETEVENTSRESPONSE = _descriptor.Descriptor(
  name='GetEventsResponse',
  full_name='grid.v1.GetEventsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='events', full_name='grid.v1.GetEventsResponse.events', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='events', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='continue_token', full_name='grid.v1.GetEventsResponse.continue_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='continueToken', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=557,
  serialized_end=655,
)


_WATCHEVENTSREQUEST = _descriptor.Descriptor(
  name='WatchEventsRequest',
  full_name='grid.v1.WatchEventsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='filter', full_name='grid.v1.WatchEventsRequest.filter', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='filter', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=657,
  serialized_end=723,
)


_WATCHEVENTSRESPONSE = _descriptor.Descriptor(
  name='WatchEventsResponse',
  full_name='grid.v1.WatchEventsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='events', full_name='grid.v1.WatchEventsResponse.events', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='events', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=725,
  serialized_end=786,
)

_EVENTFILTER.fields_by_name['resource_type'].enum_type = grid_dot_v1_dot_event__pb2._RESOURCETYPE
_EVENTFILTER.fields_by_name['event_type'].enum_type = grid_dot_v1_dot_event__pb2._EVENTTYPE
_GETEVENTSREQUEST.fields_by_name['filter'].message_type = _EVENTFILTER
_GETEVENTSREQUEST.fields_by_name['from'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_GETEVENTSREQUEST.fields_by_name['to'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_GETEVENTSRESPONSE.fields_by_name['events'].message_type = grid_dot_v1_dot_event__pb2._EVENT
_WATCHEVENTSREQUEST.fields_by_name['filter'].message_type = _EVENTFILTER
_WATCHEVENTSRESPONSE.fields_by_name['events'].message_type = grid_dot_v1_dot_event__pb2._EVENT
DESCRIPTOR.message_types_by_name['EventFilter'] = _EVENTFILTER
DESCRIPTOR.message_types_by_name['GetEventsRequest'] = _GETEVENTSREQUEST
DESCRIPTOR.message_types_by_name['GetEventsResponse'] = _GETEVENTSRESPONSE
DESCRIPTOR.message_types_by_name['WatchEventsRequest'] = _WATCHEVENTSREQUEST
DESCRIPTOR.message_types_by_name['WatchEventsResponse'] = _WATCHEVENTSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

EventFilter = _reflection.GeneratedProtocolMessageType('EventFilter', (_message.Message,), {
  'DESCRIPTOR' : _EVENTFILTER,
  '__module__' : 'grid.v1.event_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.EventFilter)
  })
_sym_db.RegisterMessage(EventFilter)

GetEventsRequest = _reflection.GeneratedProtocolMessageType('GetEventsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETEVENTSREQUEST,
  '__module__' : 'grid.v1.event_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.GetEventsRequest)
  })
_sym_db.RegisterMessage(GetEventsRequest)

GetEventsResponse = _reflection.GeneratedProtocolMessageType('GetEventsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETEVENTSRESPONSE,
  '__module__' : 'grid.v1.event_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.GetEventsResponse)
  })
_sym_db.RegisterMessage(GetEventsResponse)

WatchEventsRequest = _reflection.GeneratedProtocolMessageType('WatchEventsRequest', (_message.Message,), {
  'DESCRIPTOR' : _WATCHEVENTSREQUEST,
  '__module__' : 'grid.v1.event_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.WatchEventsRequest)
  })
_sym_db.RegisterMessage(WatchEventsRequest)

WatchEventsResponse = _reflection.GeneratedProtocolMessageType('WatchEventsResponse', (_message.Message,), {
  'DESCRIPTOR' : _WATCHEVENTSRESPONSE,
  '__module__' : 'grid.v1.event_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.WatchEventsResponse)
  })
_sym_db.RegisterMessage(WatchEventsResponse)


DESCRIPTOR._options = None

_EVENTSERVICE = _descriptor.ServiceDescriptor(
  name='EventService',
  full_name='grid.v1.EventService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=789,
  serialized_end=947,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetEvents',
    full_name='grid.v1.EventService.GetEvents',
    index=0,
    containing_service=None,
    input_type=_GETEVENTSREQUEST,
    output_type=_GETEVENTSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='WatchEvents',
    full_name='grid.v1.EventService.WatchEvents',
    index=1,
    containing_service=None,
    input_type=_WATCHEVENTSREQUEST,
    output_type=_WATCHEVENTSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_EVENTSERVICE)

DESCRIPTOR.services_by_name['EventService'] = _EVENTSERVICE

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from grid.protos.grid.v1 import user_service_pb2 as grid_dot_v1_dot_user__service__pb2


class UserServiceStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.CreateUser = channel.unary_unary(
        '/grid.v1.UserService/CreateUser',
        request_serializer=grid_dot_v1_dot_user__service__pb2.CreateUserRequest.SerializeToString,
        response_deserializer=grid_dot_v1_dot_user__service__pb2.CreateUserResponse.FromString,
        )
    self.GetUser = channel.unary_unary(
        '/grid.v1.UserService/GetUser',
        request_serializer=grid_dot_v1_dot_user__service__pb2.GetUserRequest.SerializeToString,
        response_deserializer=grid_dot_v1_dot_user__service__pb2.GetUserResponse.FromString,
        )
    self.ListUsers = channel.unary_unary(
        '/grid.v1.UserService/ListUsers',
        request_serializer=grid_dot_v1_dot_user__service__pb2.ListUsersRequest.SerializeToString,
        response_deserializer=grid_dot_v1_dot_user__service__pb2.ListUsersResponse.FromString,
        )
    self.UpdateUser = channel.unary_unary(
        '/grid.v1.UserService/UpdateUser',
        request_serializer=grid_dot_v1_dot_user__service__pb2.UpdateUserRequest.SerializeToString,
        response_deserializer=grid_dot_v1_dot_user__service__pb2.UpdateUserResponse.FromString,
        )
    self.UpdateUserStatus = channel.unary_unary(
        '/grid.v1.UserService/UpdateUserStatus',
        request_serializer=grid_dot_v1_dot_user__service__pb2.UpdateUserStatusRequest.SerializeToString,
        response_deserializer=grid_dot_v1_dot_user__service__pb2.UpdateUserStatusResponse.FromString,
        )
    self.DeleteUser = channel.unary_unary(
        '/grid.v1.UserService/DeleteUser',
        request_serializer=grid_dot_v1_dot_user__service__pb2.DeleteUserRequest.SerializeToString,
        response_deserializer=grid_dot_v1_dot_user__service__pb2.DeleteUserResponse.FromString,
        )
    self.WatchUsers = channel.unary_stream(
        '/grid.v1.UserService/WatchUsers',
        request_serializer=grid_dot_v1_dot_user__service__pb2.WatchUsersRequest.SerializeToString,
        response_deserializer=grid_dot_v1_dot_user__service__pb2.WatchUsersResponse.FromString,
        )
    self.StopUserWorkloads = channel.unary_unary(
        '/grid.v1.UserService/StopUserWorkloads',
        request_serializer=grid_dot_v1_dot_user__service__pb2.StopUserWorkloadsRequest.SerializeToString,
        response_deserializer=grid_dot_v1_dot_user__service__pb2.StopUserWorkloadsResponse.FromString,
        )


class UserServiceServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def CreateUser(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetUser(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListUsers(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def UpdateUser(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def UpdateUserStatus(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteUser(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def WatchUsers(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def StopUserWorkloads(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_UserServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'CreateUser': grpc.unary_unary_rpc_method_handler(
          servicer.CreateUser,
          request_deserializer=grid_dot_v1_dot_user__service__pb2.CreateUserRequest.FromString,
          response_serializer=grid_dot_v1_dot_user__service__pb2.CreateUserResponse.SerializeToString,
      ),
      'GetUser': grpc.unary_unary_rpc_method_handler(
          servicer.GetUser,
          request_deserializer=grid_dot_v1_dot_user__service__pb2.GetUserRequest.FromString,
          response_serializer=grid_dot_v1_dot_user__service__pb2.GetUserResponse.SerializeToString,
      ),
      'ListUsers': grpc.unary_unary_rpc_method_handler(
          servicer.ListUsers,
          request_deserializer=grid_dot_v1_dot_user__service__pb2.ListUsersRequest.FromString,
          response_serializer=grid_dot_v1_dot_user__service__pb2.ListUsersResponse.SerializeToString,
      ),
      'UpdateUser': grpc.unary_unary_rpc_method_handler(
          servicer.UpdateUser,
          request_deserializer=grid_dot_v1_dot_user__service__pb2.UpdateUserRequest.FromString,
          response_serializer=grid_dot_v1_dot_user__service__pb2.UpdateUserResponse.SerializeToString,
      ),
      'UpdateUserStatus': grpc.unary_unary_rpc_method_handler(
          servicer.UpdateUserStatus,
          request_deserializer=grid_dot_v1_dot_user__service__pb2.UpdateUserStatusRequest.FromString,
          response_serializer=grid_dot_v1_dot_user__service__pb2.UpdateUserStatusResponse.SerializeToString,
      ),
      'DeleteUser': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteUser,
          request_deserializer=grid_dot_v1_dot_user__service__pb2.DeleteUserRequest.FromString,
          response_serializer=grid_dot_v1_dot_user__service__pb2.DeleteUserResponse.SerializeToString,
      ),
      'WatchUsers': grpc.unary_stream_rpc_method_handler(
          servicer.WatchUsers,
          request_deserializer=grid_dot_v1_dot_user__service__pb2.WatchUsersRequest.FromString,
          response_serializer=grid_dot_v1_dot_user__service__pb2.WatchUsersResponse.SerializeToString,
      ),
      'StopUserWorkloads': grpc.unary_unary_rpc_method_handler(
          servicer.StopUserWorkloads,
          request_deserializer=grid_dot_v1_dot_user__service__pb2.StopUserWorkloadsRequest.FromString,
          response_serializer=grid_dot_v1_dot_user__service__pb2.StopUserWorkloadsResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'grid.v1.UserService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



from typing import Optional

import click

from grid.cli import rich_click
from grid.cli.client import Grid
import grid.cli.globals as env


@click.option('--username', type=str, help='Username used in Grid')
@click.option('--key', type=str, help='API Key from Grid')
@rich_click.command()
def login(username: Optional[str] = None, key: Optional[str] = None) -> None:
    """Authorize the CLI to access Grid AI resources for a particular user.

    If no username or key is provided, the CLI will prompt for them. After
    providing your username, a web browser will open to your account settings
    page where your API key can be found.
    """
    client = Grid(load_local_credentials=False)

    # Prompt the user for username and API Key.
    # We ask for the username first because that's
    # the same as their Github usernames.
    if not username:
        username = click.prompt('Please provide your Grid or GitHub username')
    if not key:
        settings_url = env.GRID_URL.replace("graphql", "") + "#/settings?tabId=apikey"
        click.launch(settings_url)
        key = click.prompt('Please provide your Grid API key')

    client.login(username=username, key=key)
    click.echo('Login successful. Welcome to Grid.')



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from grid.protos.grid.v1 import run_service_pb2 as grid_dot_v1_dot_run__service__pb2


class RunServiceStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.CreateRun = channel.unary_unary(
        '/grid.v1.RunService/CreateRun',
        request_serializer=grid_dot_v1_dot_run__service__pb2.CreateRunRequest.SerializeToString,
        response_deserializer=grid_dot_v1_dot_run__service__pb2.CreateRunResponse.FromString,
        )
    self.GetRun = channel.unary_unary(
        '/grid.v1.RunService/GetRun',
        request_serializer=grid_dot_v1_dot_run__service__pb2.GetRunRequest.SerializeToString,
        response_deserializer=grid_dot_v1_dot_run__service__pb2.GetRunResponse.FromString,
        )
    self.ListRuns = channel.unary_unary(
        '/grid.v1.RunService/ListRuns',
        request_serializer=grid_dot_v1_dot_run__service__pb2.ListRunsRequest.SerializeToString,
        response_deserializer=grid_dot_v1_dot_run__service__pb2.ListRunsResponse.FromString,
        )
    self.UpdateRun = channel.unary_unary(
        '/grid.v1.RunService/UpdateRun',
        request_serializer=grid_dot_v1_dot_run__service__pb2.UpdateRunRequest.SerializeToString,
        response_deserializer=grid_dot_v1_dot_run__service__pb2.UpdateRunResponse.FromString,
        )
    self.UpdateRunStatus = channel.unary_unary(
        '/grid.v1.RunService/UpdateRunStatus',
        request_serializer=grid_dot_v1_dot_run__service__pb2.UpdateRunStatusRequest.SerializeToString,
        response_deserializer=grid_dot_v1_dot_run__service__pb2.UpdateRunStatusResponse.FromString,
        )
    self.DeleteRun = channel.unary_unary(
        '/grid.v1.RunService/DeleteRun',
        request_serializer=grid_dot_v1_dot_run__service__pb2.DeleteRunRequest.SerializeToString,
        response_deserializer=grid_dot_v1_dot_run__service__pb2.DeleteRunResponse.FromString,
        )
    self.WatchRuns = channel.unary_stream(
        '/grid.v1.RunService/WatchRuns',
        request_serializer=grid_dot_v1_dot_run__service__pb2.WatchRunsRequest.SerializeToString,
        response_deserializer=grid_dot_v1_dot_run__service__pb2.WatchRunsResponse.FromString,
        )


class RunServiceServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def CreateRun(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetRun(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListRuns(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def UpdateRun(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def UpdateRunStatus(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteRun(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def WatchRuns(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_RunServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'CreateRun': grpc.unary_unary_rpc_method_handler(
          servicer.CreateRun,
          request_deserializer=grid_dot_v1_dot_run__service__pb2.CreateRunRequest.FromString,
          response_serializer=grid_dot_v1_dot_run__service__pb2.CreateRunResponse.SerializeToString,
      ),
      'GetRun': grpc.unary_unary_rpc_method_handler(
          servicer.GetRun,
          request_deserializer=grid_dot_v1_dot_run__service__pb2.GetRunRequest.FromString,
          response_serializer=grid_dot_v1_dot_run__service__pb2.GetRunResponse.SerializeToString,
      ),
      'ListRuns': grpc.unary_unary_rpc_method_handler(
          servicer.ListRuns,
          request_deserializer=grid_dot_v1_dot_run__service__pb2.ListRunsRequest.FromString,
          response_serializer=grid_dot_v1_dot_run__service__pb2.ListRunsResponse.SerializeToString,
      ),
      'UpdateRun': grpc.unary_unary_rpc_method_handler(
          servicer.UpdateRun,
          request_deserializer=grid_dot_v1_dot_run__service__pb2.UpdateRunRequest.FromString,
          response_serializer=grid_dot_v1_dot_run__service__pb2.UpdateRunResponse.SerializeToString,
      ),
      'UpdateRunStatus': grpc.unary_unary_rpc_method_handler(
          servicer.UpdateRunStatus,
          request_deserializer=grid_dot_v1_dot_run__service__pb2.UpdateRunStatusRequest.FromString,
          response_serializer=grid_dot_v1_dot_run__service__pb2.UpdateRunStatusResponse.SerializeToString,
      ),
      'DeleteRun': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteRun,
          request_deserializer=grid_dot_v1_dot_run__service__pb2.DeleteRunRequest.FromString,
          response_serializer=grid_dot_v1_dot_run__service__pb2.DeleteRunResponse.SerializeToString,
      ),
      'WatchRuns': grpc.unary_stream_rpc_method_handler(
          servicer.WatchRuns,
          request_deserializer=grid_dot_v1_dot_run__service__pb2.WatchRunsRequest.FromString,
          response_serializer=grid_dot_v1_dot_run__service__pb2.WatchRunsResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'grid.v1.RunService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



from typing import List

import click

from grid.cli import rich_click
from grid.cli.client import Grid
from grid.cli.utilities import is_experiment


@rich_click.group()
def stop():
    """Stop Runs, Experiments, or Sessions."""
    pass


@stop.command()
@rich_click.argument('experiment_ids', type=str, required=True, nargs=-1, help="The experiment IDs to stop.")
def experiment(experiment_ids: List[str]):
    """Stop one or more EXPERIMENT_IDS.

    This preserves progress completed up to this point, but stops
    further computations and any billing for the machines used.
    """
    client = Grid()
    for experiment in experiment_ids:
        if is_experiment(experiment):
            client.cancel(experiment_name=experiment)
        else:
            raise click.ClickException(f"Could not find experiment: {experiment}.")


@stop.command()
@rich_click.argument('run_ids', type=str, required=True, nargs=-1, help="The run IDs to stop.")
def run(run_ids: List[str]):
    """Stop one or more RUN_IDS.

    This preserves progress completed up to this point, but stops
    further computations and any billing for the machines used.
    """
    client = Grid()
    for run in run_ids:
        if client.is_run(run_name=run):
            client.cancel(run_name=run)
        else:
            raise click.ClickException(f"Could not find run: {run}.")


@stop.command()
@rich_click.argument('session_ids', type=str, required=True, nargs=-1, help="The session IDs to stop.")
def session(session_ids: List[str]):
    """Stop one or more SESSION_IDS.

    NOTE: stopping a session permenantly removes not only the record of the session,
          but all generated artifacts, metrics, logs, etc.
    """
    client = Grid()
    for session in session_ids:
        if client.is_interactive_node(interactive_node_name=session):
            client.delete_interactive_node(interactive_node_name=session)
        else:
            raise click.ClickException(f"Could not find session: {session}.")
